@@ -1,19 +1,17 @@
 package UNIVERSAL::filename;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 BEGIN {
     require UNIVERSAL;
 }
 
-package UNIVERSAL;
-
-sub filename {
+*UNIVERSAL::filename = sub {
     my $class = shift;
     $class =~ s{::}{/}g;
     $INC{$class.".pm"};
-}
+} unless defined &UNIVERSAL::filename;
 
 1;
 __END__
